<?php
error_reporting(0); // This will suppress all errors
?>
<?php
include "includes/header.php";
?>

<body class="hold-transition sidebar-mini layout-fixed">
    <div class="wrapper">
        <?php include "includes/sidebar.php"; ?>
        <main class="page-content">
            <div class="page-breadcrumb d-none d-sm-flex align-items-center mb-3">
                <div class="breadcrumb-Category pe-3">Geographical Area Summary</div>
                <div class="ps-3">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb mb-0 p-0">
                            <li class="breadcrumb-item"><a href="javascript:;"><i class="bx bx-home-alt"></i></a></li>
                            <li class="breadcrumb-item active" aria-current="page">Summary</li>
                        </ol>
                    </nav>
                </div>
            </div>

            <div class="row">
                <div class="col-md-12">
                    <div class="card">
                        <div class="card-body">
                            <div class="row mb-3">
                                <div class="col-md-4">
                                    <label for="selectedDate" class="form-label">Select Date:</label>
                                    <input type="date" id="selectedDate" class="form-control" value="<?php echo isset($_POST['selectedDate']) ? $_POST['selectedDate'] : date('Y-m-d'); ?>">
                                </div>
                                <div class="col-md-4">
                                    <button id="fetchData" class="btn btn-primary" style="margin-top: 1.9rem;">Fetch Data</button>
                                </div>
                            </div>
                            <div class="table-responsive" style="overflow-x:auto;">
                                <table id="example2" class="table table-striped table-bordered">
                                    <thead class="thead-dark">
                                        <tr>
                                            <th>Geographical Area</th>
                                            <th>Total Number of Drops</th>
                                            <th>Collected Revenues (USD)</th>
                                            <th>Collected Revenues (LBP)</th>
                                            <th>Number of Non-Picked Items</th>
                                        </tr>
                                    </thead>
                                    <tbody id="sortable">
                                        <?php
                                        $selectedDate = isset($_POST['selectedDate']) ? $_POST['selectedDate'] : date('Y-m-d');

                                        // Fetch data from GeographicalAreas
                                        $areasQuery = "SELECT id, Category FROM GeographicalAreas";
                                        $areasResult = $connection->query($areasQuery);

                                        $areasData = [];
                                        while ($area = $areasResult->fetch_assoc()) {
                                            $areasData[$area['id']] = [
                                                'Category' => $area['Category'],
                                                'TotalDrops' => 0,
                                                'CollectedRevenuesUSD' => 0,
                                                'CollectedRevenuesLBP' => 0,
                                                'NonPickedItems' => 0
                                            ];
                                        }

                                        // Fetch data from Drops
                                        $dropsQuery = "SELECT id, CategoryID FROM Drops";
                                        $dropsResult = $connection->query($dropsQuery);

                                        $dropsData = [];
                                        while ($drop = $dropsResult->fetch_assoc()) {
                                            $dropsData[$drop['id']] = $drop['CategoryID'];
                                            if (isset($areasData[$drop['CategoryID']])) {
                                                $areasData[$drop['CategoryID']]['TotalDrops']++;
                                            }
                                        }

                                        // Fetch data from orders
                                        $ordersQuery = "SELECT checkpoint, fees, currency, insurance, insuranceCurrency, dropped_by, Status FROM orders WHERE DATE(picked_at) = ?";
                                        $stmt = $connection->prepare($ordersQuery);
                                        $stmt->bind_param("s", $selectedDate);
                                        $stmt->execute();
                                        $ordersResult = $stmt->get_result();

                                        while ($order = $ordersResult->fetch_assoc()) {
                                            $checkpoint = $order['checkpoint'];
                                            if (isset($dropsData[$checkpoint])) {
                                                $areaId = $dropsData[$checkpoint];

                                                $fees = floatval($order['fees']);
                                                $insurance = floatval($order['insurance']);
                                                $dropped_date = new DateTime($order['dropped_by']);
                                                $current_date = new DateTime();
                                                $interval = $dropped_date->diff($current_date);
                                                $total_days = $interval->days;
                                                $overcharge = max(0, $total_days - 3);

                                                if ($order['currency'] == 'USD') {
                                                    $areasData[$areaId]['CollectedRevenuesUSD'] += $fees;
                                                } else if ($order['currency'] == 'LBP') {
                                                    $areasData[$areaId]['CollectedRevenuesLBP'] += $fees;
                                                }

                                                if ($order['insuranceCurrency'] == 'USD') {
                                                    $areasData[$areaId]['CollectedRevenuesUSD'] += $insurance;
                                                } else if ($order['insuranceCurrency'] == 'LBP') {
                                                    $areasData[$areaId]['CollectedRevenuesLBP'] += $insurance;
                                                }

                                                $areasData[$areaId]['CollectedRevenuesUSD'] += $overcharge;

                                                if ($order['Status'] == 1) {
                                                    $areasData[$areaId]['NonPickedItems']++;
                                                }
                                            }
                                        }

                                        foreach ($areasData as $area) {
                                            echo '<tr>';
                                            echo '<td>' . htmlspecialchars($area['Category']) . '</td>';
                                            echo '<td>' . htmlspecialchars($area['TotalDrops']) . '</td>';
                                            echo '<td>' . htmlspecialchars($area['CollectedRevenuesUSD']) . ' USD</td>';
                                            echo '<td>' . htmlspecialchars($area['CollectedRevenuesLBP']) . ' LBP</td>';
                                            echo '<td>' . htmlspecialchars($area['NonPickedItems']) . '</td>';
                                            echo '</tr>';
                                        }
                                        ?>
                                    </tbody>
                                </table>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </main>

<script>
    document.getElementById('fetchData').addEventListener('click', function() {
        var selectedDate = document.getElementById('selectedDate').value;
        var form = document.createElement('form');
        form.method = 'POST';
        form.action = '';
        
        var inputDate = document.createElement('input');
        inputDate.type = 'hidden';
        inputDate.name = 'selectedDate';
        inputDate.value = selectedDate;

        form.appendChild(inputDate);
        document.body.appendChild(form);
        form.submit();
    });
</script>
<?php include "includes/footer.php"; ?>
