<?php
include "includes/header.php";
?>

<body class="hold-transition sidebar-mini layout-fixed">
    <div class="wrapper">

        <?php include "includes/sidebar.php"; ?>

        <main class="page-content">
            <div class="page-breadcrumb d-none d-sm-flex align-items-center mb-3">
                <div class="breadcrumb-title pe-3">Relay Points</div>
                <div class="ps-3">
                    <nav aria-label="breadcrumb">
                        <ol class="breadcrumb mb-0 p-0">
                            <li class="breadcrumb-item"><a href="javascript:;"><i class="bx bx-home-alt"></i></a></li>
                            <li class="breadcrumb-item active" aria-current="page">Relay Points</li>
                        </ol>
                    </nav>
                </div>
            </div>
            <div>
                <strong>Color Explanation:</strong>
                <ul>
                    <li><span class="badge bg-danger">Red</span> for Requests</li>
                    <li><span class="badge bg-warning">Yellow</span> for Held for Storage</li>
                    <li><span class="badge bg-primary">Blue</span> for In-Stock</li>
                    <li><span class="badge bg-success">Green</span> for Picked-Up</li>
                </ul>
            </div>
            <?php
                $stmt = $connection->prepare("SELECT id, Name, OpeningHours, PhoneNumber FROM Drops");
                $stmt->execute();
                $result = $stmt->get_result();

                if ($result->num_rows > 0) {
                    echo '<div class="row">';
                    while ($row = $result->fetch_assoc()) {
                        $dropId = $row['id'];

                        // Prepare and execute the statement to get the order counts for unviewed orders
                        $orderStmt = $connection->prepare("SELECT 
                            SUM(CASE WHEN Status = 0 AND Viewed = 0 THEN 1 ELSE 0 END) as requests,
                            SUM(CASE WHEN Status = 3 AND Viewed = 0 THEN 1 ELSE 0 END) as held_for_storage,
                            SUM(CASE WHEN Status = 1 AND Viewed = 0 THEN 1 ELSE 0 END) as in_stock,
                            SUM(CASE WHEN Status = 2 AND Viewed = 0 THEN 1 ELSE 0 END) as picked_up
                            FROM orders WHERE checkpoint = ?");
                        $orderStmt->bind_param("i", $dropId);
                        $orderStmt->execute();
                        $orderResult = $orderStmt->get_result();
                        $orderCounts = $orderResult->fetch_assoc();

                        // Check if there are any unviewed orders
                        $totalUnviewedOrders = $orderCounts["requests"] + $orderCounts["held_for_storage"] + $orderCounts["in_stock"] + $orderCounts["picked_up"];

                        echo '
                        <div class="col-lg-3">
                            <a href="RelayPointDetails.php?id=' . htmlspecialchars($row["id"]) . '" class="drop-link" data-drop-id="' . htmlspecialchars($row["id"]) . '" style="text-decoration: none; color: inherit;">
                                <div class="card shadow-sm border-0 overflow-hidden" style="background-color: lightcyan;">
                                    <div class="card-body">';
                                    
                                    if ($totalUnviewedOrders > 0) {
                                        echo '<div class="d-flex justify-content-end">
                                            <div class="notifications">
                                                <span class="badge bg-danger">' . $orderCounts["requests"] . '</span>
                                                <span class="badge bg-warning">' . $orderCounts["held_for_storage"] . '</span>
                                                <span class="badge bg-primary">' . $orderCounts["in_stock"] . '</span>
                                                <span class="badge bg-success">' . $orderCounts["picked_up"] . '</span>
                                            </div>
                                        </div>';
                                    }
                                    
                                    echo '<div class="d-flex justify-content-between align-items-center">
                                            <div class="text-center mt-4">
                                                <h4 class="mb-1">' . htmlspecialchars($row["Name"]) . '</h4>
                                                <div class="mt-4">#' . htmlspecialchars($row["id"]) . '</div>
                                                <h6 class="mb-1">' . htmlspecialchars($row["OpeningHours"]) . '</h6>
                                                <p class="mb-0 text-secondary">' . htmlspecialchars($row["PhoneNumber"]) . '</p>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </a>
                        </div>';
                    }
                    echo '</div>';
                } else {
                    echo 'No drops available.';
                }

                $stmt->close();
                $orderStmt->close();
                $connection->close();
                ?>

        </main>
        <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.7.1/jquery.min.js"
            integrity="sha512-v2CJ7UaYy4JwqLDIrZUI/4hqeoQieOmAZNXBeQyjo21dadnwR+8ZaIJVT8EE2iyI61OV8e6M8PP2/4hpQINQ/g=="
            crossorigin="anonymous" referrerpolicy="no-referrer"></script>
        <script>
            document.addEventListener('DOMContentLoaded', function () {
                const dropLinks = document.querySelectorAll('a.drop-link');

                dropLinks.forEach(link => {
                    link.addEventListener('click', function (event) {
                        event.preventDefault();

                        const dropId = this.dataset.dropId;

                        // AJAX call to mark orders as viewed
                        const xhr = new XMLHttpRequest();
                        xhr.open('POST', 'markOrdersViewed.php', true);
                        xhr.setRequestHeader('Content-Type',
                            'application/x-www-form-urlencoded');
                        xhr.onreadystatechange = function () {
                            if (xhr.readyState === 4 && xhr.status === 200) {
                                console.log('Orders marked as viewed');
                                // Redirect to the drop details page
                                window.location.href = `RelayPointDetails.php?id=${dropId}`;
                            }
                        };
                        xhr.send(`dropId=${dropId}`);
                    });
                });
            });
        </script>

        <?php include "includes/footer.php"; ?>
