<?php
require_once '../includes/db.php';

// Get phone number and password from POST request
$phoneNumber = $_POST['phone_number'] ?? '';
$password = $_POST['password'] ?? '';

// Prepare the response array
$response = [];

// Check if both phone number and password are provided
if (empty($phoneNumber) || empty($password)) {
    $response = ['error' => true, 'message' => 'Phone number and password are required.'];
    echo json_encode($response);
    exit;
}

// Prepare SQL statement to select user with the given phone number
$stmt = $connection->prepare("SELECT * FROM Users WHERE PhoneNumber = ?");
$stmt->bind_param("s", $phoneNumber);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $user = $result->fetch_assoc();

    // Check if the user is banned
    if ($user['Status'] == 1) {
        $response = ['error' => true, 'message' => 'Your account has been banned.'];
    } else {
        // Verify the password
        if (password_verify($password, $user['Password'])) {
            // Successful login
            $response = [
                'error' => false,
                'message' => 'Login successful.',
                'user' => [
                    'id' => $user['id'],
                    'phoneNumber' => $user['PhoneNumber'],
                    'fullName' => $user['FullName'],
                    'email' => $user['Email'],
                ],
            ];
        } else {
            // Incorrect password
            $response = ['error' => true, 'message' => 'Incorrect password.'];
        }
    }
} else {
    // Phone number does not exist
    $response = ['error' => true, 'message' => 'Phone number does not exist.'];
}

$stmt->close();
$connection->close();

echo json_encode($response);
?>
