<?php
require_once '../vendor/autoload.php'; // Adjust the path as needed
require_once '../includes/db.php'; // Include your DB connection

// Retrieve the phoneNumber and deletionCode from the request
$phoneNumber = $_POST['phoneNumber'] ?? '';
$userId = $_POST['userId'] ?? '';
$deletionCode = $_POST['deletionCode'] ?? '';

// Check if the phoneNumber, userId, and deletionCode are provided
if (empty($phoneNumber) || empty($userId) || empty($deletionCode)) {
    echo json_encode(['error' => 'Phone number, user ID, and deletion code are required.']);
    exit;
}

// Verify the deletion code
$stmt = $connection->prepare("SELECT * FROM user_deletion_codes WHERE phone_number = ? AND verification_code = ?");
$stmt->bind_param("ss", $phoneNumber, $deletionCode);
$stmt->execute();
$result = $stmt->get_result();
$stmt->close();

if ($result->num_rows == 0) {
    echo json_encode(['error' => 'Invalid deletion code.']);
    exit;
}

// If the code is correct, proceed to delete the user account
$stmt = $connection->prepare("DELETE FROM Users WHERE id = ?");
$stmt->bind_param("s", $userId);
$success = $stmt->execute();
$stmt->close();

if ($success) {
    // Optionally, delete the associated deletion code record
    $stmt = $connection->prepare("DELETE FROM user_deletion_codes WHERE phone_number = ?");
    $stmt->bind_param("s", $phoneNumber);
    $stmt->execute();
    $stmt->close();

    echo json_encode(['message' => 'Account deleted successfully']);
} else {
    echo json_encode(['error' => 'Failed to delete the account.']);
}
?>
